@@ -3,22 +3,21 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
+ * Reserved.  This file contains Original Code and/or Modifications of
+ * Original Code as defined in and that are subject to the Apple Public
+ * Source License Version 1.1 (the "License").  You may not use this file
+ * except in compliance with the License.  Please obtain a copy of the
+ * License at http://www.apple.com/publicsource and read it before using
+ * this file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -156,8 +155,10 @@ enum bool launched = FALSE;
 enum bool executable_prebound = FALSE;
 
 static struct segment_command *data_seg;
+#if 0 /* disable until NXProtectZone() works again */
 static void get_data_segment(
     void);
+#endif
 
 /*
  * The variable executables_path is an absolute path of the executable being
@@ -522,6 +523,7 @@ char *envp[])
 		                sizeof("DYLD_TRACE=") - 1) == 0){
 		    dyld_trace = TRUE;
 		}
+#if 0 /* disable until NXProtectZone() works again */
 		else if(strncmp(*p, "DYLD_MEM_PROTECT=",
 		                sizeof("DYLD_MEM_PROTECT=") - 1) == 0){
 		    dyld_mem_protect = TRUE;
@@ -531,6 +533,7 @@ char *envp[])
 		    mem_prot_debug_lock = *debug_thread_lock;
 		    debug_thread_lock = &mem_prot_debug_lock;
 		}
+#endif
 		else if(strncmp(*p, "DYLD_EBADEXEC_ONLY=",
 		                sizeof("DYLD_EBADEXEC_ONLY=") - 1) == 0){
 		    dyld_ebadexec_only = TRUE;
@@ -675,6 +678,7 @@ void)
 }
 #endif /* DYLD_PROFILING */
 
+#if 0 /* disable until NXProtectZone() works again */
 /*
  * get_data_segment() sets data_seg to point at the data segment command for the
  * dynamic linker.
@@ -700,6 +704,7 @@ void)
 	}
 	data_seg = NULL;
 }
+#endif
 
 void
 protect_data_segment(
