@@ -3,28 +3,27 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
+ * Reserved.  This file contains Original Code and/or Modifications of
+ * Original Code as defined in and that are subject to the Apple Public
+ * Source License Version 1.1 (the "License").  You may not use this file
+ * except in compliance with the License.  Please obtain a copy of the
+ * License at http://www.apple.com/publicsource and read it before using
+ * this file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
 #ifdef SHLIB
 #include "shlib.h"
-#endif SHLIB
+#endif /* SHLIB */
 /*
  * This file contains the routines that deal with indirect sections (both
  * lazy and non-lazy symbol pointer sections as well as symbol stub sections). 
@@ -173,7 +172,7 @@ struct section_map *section_map)
 #ifdef DEBUG
 	data->nfiles++;
 	data->nitems += nitems;
-#endif DEBUG
+#endif /* DEBUG */
 
 	/*
 	 * First deal with the contents of the indirect section and determine
@@ -371,7 +370,11 @@ printf("in indirect_section_merge() got INDIRECT_SYMBOL_LOCAL or INDIRECT_SYMBOL
 			(merged_symbol->definition_object->section_maps[
 			 merged_symbol->nlist.n_sect - 1].
 			 s->flags & SECTION_TYPE) == S_COALESCED){
-		    if(output_for_dyld && has_dynamic_linker_command)
+		    if(output_for_dyld && has_dynamic_linker_command &&
+		       (((merged_symbol->nlist.n_desc & N_WEAK_DEF) !=
+			 N_WEAK_DEF) ||
+		       ((merged_symbol->nlist.n_type & N_PEXT) == N_PEXT &&
+			keep_private_externs == FALSE) ) )
 			fine_relocs[i].indirect_defined = TRUE;
 		    else
 			fine_relocs[i].indirect_defined = FALSE;
@@ -383,7 +386,7 @@ printf("in indirect_section_merge() got INDIRECT_SYMBOL_LOCAL or INDIRECT_SYMBOL
 		if((merged_symbol->nlist.n_type & N_TYPE) == N_ABS)
 		    section_map->absolute_indirect_defineds = TRUE;
 
-		if(filetype == MH_DYLIB ||
+		if((filetype == MH_DYLIB && multi_module_dylib == TRUE) ||
 		   section_type == S_NON_LAZY_SYMBOL_POINTERS ||
 		   fine_relocs[i].indirect_defined == FALSE){
 		    fine_relocs[i].output_offset = lookup_indirect_item(
@@ -682,15 +685,16 @@ account_for_size:
 		    merged_symbol = (struct merged_symbol *)
 				    merged_symbol->nlist.n_value;
 		/*
-		 * For dynamic shared library format files the merged sections
-		 * that could have had external relocation entries must be
-		 * resolved to private extern symbols.  This is because for
-		 * MH_DYLIB files all modules share the merged sections and the
-		 * entire section gets relocated when the library is mapped in.
-		 * So the above restriction assures the merged section will get
-		 * relocated properly and can be shared amoung library modules.
+		 * For multi module dynamic shared library format files the
+		 * merged sections that could have had external relocation
+		 * entries must be resolved to private extern symbols.  This is
+		 * because for multi module MH_DYLIB files all modules share the
+		 * merged sections and the entire section gets relocated when
+		 * the library is mapped in. So the above restriction assures
+		 * the merged section will get relocated properly and can be
+		 * shared amoung library modules.
 		 */
-		if(filetype == MH_DYLIB){
+		if(filetype == MH_DYLIB && multi_module_dylib == TRUE){
 		    /*
 		     * If the symbol is undefined or not a private extern it is
 		     * an error for in this section for a MH_DYLIB file.
@@ -701,19 +705,20 @@ account_for_size:
 			merged_symbol->defined_in_dylib == TRUE)){
 			if(merged_symbol->error_flagged_for_dylib == 0){
 			    error_with_cur_obj("illegal undefined reference "
-				"for MH_DYLIB output file to symbol: %s from "
-				"section (%.16s,%.16s) relocation entry: %lu",
-				merged_symbol->nlist.n_un.n_name,
-				s->segname, s->sectname, i);
+				"for multi module MH_DYLIB output file to "
+				"symbol: %s from section (%.16s,%.16s) "
+				"relocation entry: %lu",
+				merged_symbol->nlist.n_un.n_name, s->segname,
+				s->sectname, i);
 			    merged_symbol->error_flagged_for_dylib = 1;
 			}
 		    }
 		    else if((merged_symbol->nlist.n_type & N_PEXT) != N_PEXT){
 			if(merged_symbol->error_flagged_for_dylib == 0){
 			    error_with_cur_obj("illegal external reference for "
-				"MH_DYLIB output file to symbol: %s (not a "
-				"private extern symbol) from section (%.16s,"
-				"%.16s) relocation entry: %lu",
+				"multi module MH_DYLIB output file to symbol: "
+				"%s (not a private extern symbol) from section "
+				"(%.16s,%.16s) relocation entry: %lu",
 				merged_symbol->nlist.n_un.n_name,
 				s->segname, s->sectname, i);
 			    merged_symbol->error_flagged_for_dylib = 1;
@@ -757,18 +762,19 @@ account_for_size:
 		/*
 		 * The number of relocation entries in the output file is based
 		 * on one of three different cases:
-		 *  The output file is a dynamic shared library file
+		 *  The output file is a multi module dynamic shared library
 		 *  The output file has a dynamic linker load command
 		 *  The output does not have a dynamic linker load command
 		 */
-		if(filetype == MH_DYLIB){
+		if(filetype == MH_DYLIB && multi_module_dylib == TRUE){
 		    /*
-		     * For dynamic shared library files there are no external
-		     * relocation entries that will be left as external as
-		     * checked above.  Only non-position-independent local
-		     * relocation entries are kept.  Modules of dylibs are not
-		     * linked together and can only be slid keeping all sections
-		     * relative to each other the same.
+		     * For multi module dynamic shared library files there are
+		     * no external relocation entries that will be left as
+		     * external as checked above.  Only non-position-independent
+		     * local relocation entries are kept.  Modules of multi
+		     * module dylibs are not linked together and can only be
+		     * slid keeping all sections relative to each other the
+		     * same.
 		     */
 		    if(pic == FALSE)
 			ms->nlocrel += 1 + pair;
@@ -829,7 +835,7 @@ account_for_size:
 		ms->s.nreloc += 1 + pair;
 		nreloc += 1 + pair;
 	    }
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 	    i += pair;
 	}
 	/*
@@ -1293,7 +1299,7 @@ void)
 	if(nindirectsyms == 0)
 	    return;
 	if(strip_level == STRIP_ALL)
-	    fatal("can't use -s with input files containg indirect symbols "
+	    fatal("can't use -s with input files containing indirect symbols "
 		  "(output file must contain at least global symbols, for "
 		  "maximum stripping use -x)");
 	indirect_symbols = (unsigned long *)(output_addr +
@@ -1376,6 +1382,6 @@ void)
 #ifndef RLD
 	output_flush(output_dysymtab_info.dysymtab_command.indirectsymoff,
 		     nindirect_symbols * sizeof(unsigned long));
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 }
 #endif /* !defined(SA_RLD) */
