@@ -3,28 +3,27 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
+ * Reserved.  This file contains Original Code and/or Modifications of
+ * Original Code as defined in and that are subject to the Apple Public
+ * Source License Version 1.1 (the "License").  You may not use this file
+ * except in compliance with the License.  Please obtain a copy of the
+ * License at http://www.apple.com/publicsource and read it before using
+ * this file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
 #ifdef SHLIB
 #include "shlib.h"
-#endif SHLIB
+#endif /* SHLIB */
 /*
  * This file contains the routines that drives the layout phase of the
  * link-editor.  In this phase the output file's addresses and offset are
@@ -151,7 +150,7 @@ static void check_for_overlapping_segments(
     struct merged_segment *outputs_linkedit_segment);
 static void print_load_map(void);
 static void print_load_map_for_objects(struct merged_section *ms);
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 /*
  * layout() is called from main() and lays out the output file.
@@ -180,7 +179,7 @@ layout(void)
 	memset(&hppa_integer_state, '\0',
 		sizeof(struct hp_pa_integer_thread_state));
 	memset(&sparc_state, '\0', sizeof(struct sparc_thread_state_regs));
-#endif RLD
+#endif /* RLD */
 	/*
 	 * First finish creating all sections that will be in the final output
 	 * file.  This involves defining common symbols which can create a
@@ -194,7 +193,7 @@ layout(void)
 	 */
 #ifndef RLD
 	process_section_specs();
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 	/*
 	 * So literal pointer sections can use indirect symbols these need to
@@ -218,7 +217,7 @@ layout(void)
 	    setup_link_editor_symbols();
 	if(filetype == MH_PRELOAD)
 	    define_link_editor_preload_symbols(TRUE);
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 	/*
 	 * Now that the alignment of all the sections has been determined (from
@@ -233,14 +232,14 @@ layout(void)
 #ifdef DEBUG
 	if(debug & (1 << 21))
 	    print_merged_section_stats();
-#endif DEBUG
+#endif /* DEBUG */
 
 #ifndef RLD
 	/*
 	 * Layout any sections that have -sectorder options specified for them.
 	 */
 	layout_ordered_sections();
-#endif RLD
+#endif /* RLD */
 
 	/*
 	 * Report undefined symbols and account for merged that will not be
@@ -264,7 +263,7 @@ layout(void)
 	   twolevel_namespace == TRUE &&
 	   multiply_defined_unused_flag != MULTIPLY_DEFINED_SUPPRESS)
 	    twolevel_namespace_check_for_unused_dylib_symbols();
-#endif RLD
+#endif /* RLD */
 
 	/*
 	 * Assign the symbol table indexes for the symbol table entries.
@@ -307,7 +306,7 @@ layout(void)
 
 	if(load_map)
 	    print_load_map();
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 #ifdef DEBUG
 	if(debug & (1 << 7)){
@@ -320,7 +319,7 @@ layout(void)
 	    print_symbol_list("after layout", FALSE);
 	if(debug & (1 << 20))
 	    print_object_list();
-#endif DEBUG
+#endif /* DEBUG */
 }
 
 #if defined(RLD) && !defined(SA_RLD) && !(defined(KLD) && defined(__STATIC__))
@@ -421,7 +420,7 @@ layout_segments(void)
     enum bool address_zero_specified;
     struct merged_dylib *mdl;
     struct dynamic_library *dp;
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
     struct merged_symbol *merged_symbol;
 
     static struct merged_segment linkedit_segment = { {0} };
@@ -431,7 +430,7 @@ layout_segments(void)
 
 #ifdef RLD
 	memset(&object_segment, '\0', sizeof(struct merged_segment));
-#endif RLD
+#endif /* RLD */
 
 	/*
 	 * If the file type is MH_OBJECT then place all the sections in one
@@ -443,7 +442,7 @@ layout_segments(void)
 	    zerofill = &(object_segment.zerofill_sections);
 #ifdef RLD
 	    original_merged_segments = merged_segments;
-#endif RLD
+#endif /* RLD */
 	    p = &merged_segments;
 	    while(*p){
 		msg = *p;
@@ -645,6 +644,7 @@ layout_segments(void)
 		    if(strip_level != STRIP_ALL)
 			linkedit_segment.sg.filesize +=
 			    (nmerged_symbols
+			     - nstripped_merged_symbols
 			     + nlocal_symbols
 			     - nmerged_symbols_referenced_only_from_dylibs) *
 			    sizeof(struct nlist) +
@@ -732,7 +732,7 @@ layout_segments(void)
 	 * segments.
 	 */
 	process_segment_specs();
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 #ifndef RLD
 	/*
@@ -755,7 +755,7 @@ layout_segments(void)
 		msg->prot_set = TRUE;
 	    }
 	}
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 	/*
 	 * Set the protections of segments that have not had their protection
@@ -999,6 +999,7 @@ layout_segments(void)
 	if(strip_level != STRIP_ALL){
 	    output_symtab_info.symtab_command.nsyms =
 		nmerged_symbols
+		- nstripped_merged_symbols
 		+ nlocal_symbols
 		- nmerged_symbols_referenced_only_from_dylibs;
 	    output_symtab_info.symtab_command.strsize =
@@ -1065,7 +1066,8 @@ layout_segments(void)
 		output_thread_info.thread_command.cmdsize += sizeof(long) *
 					    M68K_THREAD_STATE_REGS_COUNT;
 	    }
-	    else if(arch_flag.cputype == CPU_TYPE_POWERPC){
+	    else if(arch_flag.cputype == CPU_TYPE_POWERPC ||
+		    arch_flag.cputype == CPU_TYPE_VEO){
 		output_thread_info.flavor = PPC_THREAD_STATE;
 		output_thread_info.count = PPC_THREAD_STATE_COUNT;
 		output_thread_info.entry_point = (int *)&(powerpc.srr0);
@@ -1357,7 +1359,7 @@ layout_segments(void)
 	    else
 		first_msg->sg.vmaddr = (long)output_addr + headers_size;
 	}
-#endif RLD
+#endif /* RLD */
 	/*
 	 * Set the addresses of segments that have not had their addresses set
 	 * and set the addresses of all sections (previously set relitive to the
@@ -1415,7 +1417,7 @@ layout_segments(void)
 	check_for_overlapping_segments(&linkedit_segment);
 	if(prebinding)
 	    output_mach_header.flags |= MH_PREBOUND;
-#endif RLD
+#endif /* RLD */
 
 	/*
 	 * Assign all file offsets.  Things with offsets appear in the following
@@ -1506,7 +1508,7 @@ layout_segments(void)
 	 * strip_level != STRIP_ALL.
 	 */
 	offset = output_size;
-#endif RLD
+#endif /* RLD */
 
 	/* the linkedit segment will start here */
 	linkedit_segment.sg.fileoff = offset;
@@ -1577,7 +1579,7 @@ layout_segments(void)
 	    offset += output_dysymtab_info.dysymtab_command.nextrefsyms *
 		      sizeof(struct dylib_reference);
 	}
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 	/* set the offset to the symbol table (output not for dyld case) */
 	if(output_for_dyld == FALSE){
 	    if(strip_level != STRIP_ALL){
@@ -1594,7 +1596,7 @@ layout_segments(void)
 #ifndef RLD
 	/* set the size of the output file */
 	output_size = offset;
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 	/*
 	 * Set the output section number in to each merged section to be used
@@ -1636,7 +1638,7 @@ layout_segments(void)
 	    define_link_editor_dylib_symbols(first_msg->sg.vmaddr);
 	if(filetype == MH_PRELOAD)
 	    define_link_editor_preload_symbols(FALSE);
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 	/*
 	 * Now with the addresses of the segments and sections set and the
@@ -2218,7 +2220,7 @@ struct merged_section *ms)
 	    }
 	}
 }
-#endif !defined(RLD)
+#endif /* !defined(RLD) */
 
 #ifdef DEBUG
 /*
@@ -2273,4 +2275,4 @@ print_thread_info(void)
 	else
 	    print("\n");
 }
-#endif DEBUG
+#endif /* DEBUG */
