@@ -3,22 +3,21 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
+ * Reserved.  This file contains Original Code and/or Modifications of
+ * Original Code as defined in and that are subject to the Apple Public
+ * Source License Version 1.1 (the "License").  You may not use this file
+ * except in compliance with the License.  Please obtain a copy of the
+ * License at http://www.apple.com/publicsource and read it before using
+ * this file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -866,7 +865,7 @@ ppc_thread_state_t *cpu)
 	printf("      xer  0x%08x\n", cpu->xer);
 	printf("      srr1 0x%08x\n", cpu->srr1);
 }
-#endif __ppc__
+#endif /* __ppc__ */
 #ifdef hppa
 void
 printf_hp_pa_integer_thread_state(
@@ -1235,7 +1234,7 @@ task_port_t target_task)
 	 */
 	mh = NULL;
 	mh_address = 0;
-	address = 0x41100000;
+	address = 0x8fe00000;
 #ifdef __MACH30__
 	infoCnt = VM_REGION_BASIC_INFO_COUNT;
 	k = vm_region(target_task, &address, &size, VM_REGION_BASIC_INFO,
@@ -2055,7 +2054,7 @@ vm_offset_t stack_size)
 
 	return(DYLD_SUCCESS);
 }
-#endif m68k
+#endif /* m68k */
 
 #ifdef hppa
 static
@@ -2315,7 +2314,7 @@ vm_offset_t stack_size)
 
 	return(DYLD_SUCCESS);
 }
-#endif __ppc__
+#endif /* __ppc__ */
 
 /*
  * When a error occurs in the dyld debug API's the user registered function
