@@ -3,22 +3,21 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
+ * Reserved.  This file contains Original Code and/or Modifications of
+ * Original Code as defined in and that are subject to the Apple Public
+ * Source License Version 1.1 (the "License").  You may not use this file
+ * except in compliance with the License.  Please obtain a copy of the
+ * License at http://www.apple.com/publicsource and read it before using
+ * this file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -617,7 +616,10 @@ char **envp)
 		        strcmp(argv[i], "-dylib_file") == 0 ||
 		        strcmp(argv[i], "-final_output") == 0 ||
 		        strcmp(argv[i], "-headerpad") == 0 ||
-		        strcmp(argv[i], "-weak_reference_mismatches") == 0){
+		        strcmp(argv[i], "-weak_reference_mismatches") == 0 ||
+		        strcmp(argv[i], "-u") == 0 ||
+		        strcmp(argv[i], "-exported_symbols_list") == 0 ||
+		        strcmp(argv[i], "-unexported_symbols_list") == 0){
 		    if(cmd_flags.ranlib == TRUE){
 			error("unknown option: %s", argv[i]);
 			usage();
@@ -639,6 +641,7 @@ char **envp)
 		        strcmp(argv[i], "-Si") == 0 ||
 		        strcmp(argv[i], "-S") == 0 ||
 		        strcmp(argv[i], "-X") == 0 ||
+		        strcmp(argv[i], "-x") == 0 ||
 		        strcmp(argv[i], "-whatsloaded") == 0 ||
 			strcmp(argv[i], "-whyload") == 0 ||
 			strcmp(argv[i], "-arch_errors_fatal") == 0 ||
@@ -650,7 +653,9 @@ char **envp)
 			strcmp(argv[i], "-headerpad_max_install_names") == 0 ||
 			strcmp(argv[i], "-prebind_all_twolevel_modules") == 0 ||
 			strcmp(argv[i], "-ObjC") == 0 ||
-			strcmp(argv[i], "-M") == 0){
+			strcmp(argv[i], "-M") == 0 ||
+			strcmp(argv[i], "-single_module") == 0 ||
+			strcmp(argv[i], "-multi_module") == 0){
 		    if(cmd_flags.ranlib == TRUE){
 			error("unknown option: %s", argv[i]);
 			usage();
@@ -659,6 +664,13 @@ char **envp)
 				sizeof(char *) * (cmd_flags.nldflags + 1));
 		    cmd_flags.ldflags[cmd_flags.nldflags++] = argv[i];
 		}
+		else if(strcmp(argv[i], "-no_arch_warnings") == 0){
+		    if(cmd_flags.ranlib == TRUE){
+			error("unknown option: %s", argv[i]);
+			usage();
+		    }
+		    /* ignore this flag */
+		}
 		else if(strcmp(argv[i], "-prebind") == 0){
 		    if(cmd_flags.ranlib == TRUE){
 			error("unknown option: %s", argv[i]);
