@@ -3,22 +3,21 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
+ * Reserved.  This file contains Original Code and/or Modifications of
+ * Original Code as defined in and that are subject to the Apple Public
+ * Source License Version 1.1 (the "License").  You may not use this file
+ * except in compliance with the License.  Please obtain a copy of the
+ * License at http://www.apple.com/publicsource and read it before using
+ * this file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -526,7 +525,8 @@ void *cookie)
 		else
 		    symbols[i].n_un.n_name = symbols[i].n_un.n_strx + strings;
 
-		if((symbols[i].n_type & N_TYPE) == N_INDR){
+		if((symbols[i].n_type & N_STAB) == 0 &&
+		   (symbols[i].n_type & N_TYPE) == N_INDR){
 		    if(symbols[i].n_value == 0)
 			symbols[i].n_value = (long)"";
 		    else if(symbols[i].n_value > st->strsize)
@@ -797,7 +797,8 @@ char *arch_name)
 		else
 		    printf("%08x %s", (unsigned int)symbols[i].n_un.n_strx,
 			   symbols[i].n_un.n_strx + strings);
-		if((symbols[i].n_type & N_TYPE) == N_INDR){
+		if((symbols[i].n_type & N_STAB) == 0 &&
+		   (symbols[i].n_type & N_TYPE) == N_INDR){
 		    if(symbols[i].n_value == 0)
 			printf(" (indirect for %08lx (null))\n",
 			       symbols[i].n_value);
@@ -992,7 +993,8 @@ struct value_diff *value_diffs)
 		else
 		    printf("%08x %s", (unsigned int)symbols[i].n_un.n_strx,
 			   symbols[i].n_un.n_strx + strings);
-		if((symbols[i].n_type & N_TYPE) == N_INDR){
+		if((symbols[i].n_type & N_STAB) == 0 &&
+		   (symbols[i].n_type & N_TYPE) == N_INDR){
 		    if(symbols[i].n_value == 0)
 			printf(" (indirect for %08lx (null))\n",
 			       symbols[i].n_value);
@@ -1140,6 +1142,9 @@ static const struct stabnames stabnames[] = {
     { N_LSYM,  "LSYM" },
     { N_BINCL, "BINCL" },
     { N_SOL,   "SOL" },
+    { N_PARAMS,"PARAM" },
+    { N_VERSION,"VERS" },
+    { N_OLEVEL,"OLEV" },
     { N_PSYM,  "PSYM" },
     { N_EINCL, "EINCL" },
     { N_ENTRY, "ENTRY" },
