@@ -3,22 +3,21 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
+ * Portions Copyright (c) 1999 Apple Computer, Inc.  All Rights
+ * Reserved.  This file contains Original Code and/or Modifications of
+ * Original Code as defined in and that are subject to the Apple Public
+ * Source License Version 1.1 (the "License").  You may not use this file
+ * except in compliance with the License.  Please obtain a copy of the
+ * License at http://www.apple.com/publicsource and read it before using
+ * this file.
  * 
  * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON- INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -425,7 +424,7 @@ make_exthash(void)
 		extp = extp->next;
 	    }
 	}
-#endif HOST_DEBUG
+#endif /* HOST_DEBUG */
 }
 
 /*
@@ -634,7 +633,7 @@ object_list[i]->pu_symbols[l].n_value);
 			object_list[i]->pu_symbols[j].n_value);
 	    }
 	}
-#endif HOST_DEBUG
+#endif /* HOST_DEBUG */
 }
 
 /*
@@ -668,7 +667,7 @@ make_references(void)
 		extp = extp->next;
 	    }
 	}
-#endif HOST_DEBUG
+#endif /* HOST_DEBUG */
 
 	/*
 	 * Create a file definition symbol name for each host object file.
@@ -783,7 +782,7 @@ make_references(void)
 		refp = refp->next;
 	    }
 	}
-#endif HOST_DEBUG
+#endif /* HOST_DEBUG */
 }
 
 /*
